@@ -1,14 +1,14 @@
 ;;; embark-consult.el --- Consult integration for Embark -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2021-2025  Free Software Foundation, Inc.
+;; Copyright (C) 2021-2026  Free Software Foundation, Inc.
 
 ;; Author: Omar Antolín Camarena <omar@matem.unam.mx>
 ;; Maintainer: Omar Antolín Camarena <omar@matem.unam.mx>
 ;; Keywords: convenience
-;; Package-Version: 20250622.535
-;; Package-Revision: a563786d0e07
+;; Package-Version: 20260218.624
+;; Package-Revision: 0bdfd38d281d
 ;; URL: https://github.com/oantolin/embark
-;; Package-Requires: ((emacs "28.1") (compat "30") (embark "1.1") (consult "1.8"))
+;; Package-Requires: ((emacs "29.1") (compat "30") (embark "1.1") (consult "3.2"))
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -28,9 +28,6 @@
 ;; This package provides integration between Embark and Consult.  The package
 ;; will be loaded automatically by Embark.
 
-;; Some of the functionality here was previously contained in Embark
-;; itself:
-
 ;; - Support for consult-buffer, so that you get the correct actions
 ;; for each type of entry in consult-buffer's list.
 
@@ -40,24 +37,7 @@
 ;; you can export from them to an occur buffer (where occur-edit-mode
 ;; works!).
 
-;; Just load this package to get the above functionality, no further
-;; configuration is necessary.
-
-;; Additionally this package contains some functionality that has
-;; never been in Embark: access to Consult preview from auto-updating
-;; Embark Collect buffer that is associated to an active minibuffer
-;; for a Consult command.  For information on Consult preview, see
-;; Consult's info manual or its readme on GitHub.
-
-;; If you always want the minor mode enabled whenever it possible use:
-
-;; (add-hook 'embark-collect-mode-hook #'consult-preview-at-point-mode)
-
-;; If you don't want the minor mode automatically on and prefer to
-;; trigger the consult previews manually use this instead:
-
-;; (keymap-set embark-collect-mode-map "C-j"
-;;   #'consult-preview-at-point)
+;; - Enabling Consult preview in `embark-live' buffers.
 
 ;;; Code:
 
@@ -111,7 +91,10 @@ category `consult-line'."
   (let ((buf (generate-new-buffer "*Embark Export Occur*"))
         (mouse-msg "mouse-2: go to this occurrence")
         (inhibit-read-only t)
+        (affixator (embark--get-affixator 'consult-location))
         last-buf)
+    ;; Run affixator for lazy highlighting
+    (setq lines (mapcar #'car (funcall affixator lines)))
     (with-current-buffer buf
       (dolist (line lines)
         (pcase-let*
@@ -504,5 +487,9 @@ Meant as :after-until advice for `embark-collect--metadatum'."
              #'embark-consult-imenu-or-outline-candidates
              'append)
 
+;; Automatically preview in live collect buffer, see `embark-live'.
+(add-hook 'embark-collect-mode-hook
+          'consult--default-completion-list-preview-setup)
+
 (provide 'embark-consult)
 ;;; embark-consult.el ends here
